#
# spec file for package qt6-shadertools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.7.2
%define short_version 6.7
%define tar_name qtshadertools-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor docs%{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-shadertools%{?pkg_suffix}
Version:        6.7.2
Release:        1.1
Summary:        Qt 6 ShaderTools library
License:        GPL-3.0-or-later
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-shadertools-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
Requires:       spirv-tools
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
The Qt 6 ShaderTools library and tools.

%if !%{qt6_docs_flavor}

%package -n libQt6ShaderTools6
Summary:        Qt 6 ShaderTools library

%description -n libQt6ShaderTools6
The Qt 6 ShaderTools library.

%package devel
Summary:        Qt 6 ShaderTools library - Development files
Requires:       libQt6ShaderTools6 = %{version}
# qsb is required
Requires:       qt6-shadertools = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}

%description devel
Development files for the Qt 6 ShaderTools library

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 ShaderTools library
Requires:       cmake(Qt6ShaderTools) = %{real_version}
%requires_eq    qt6-gui-private-devel

%description private-devel
This package provides private headers of libQt6ShaderTools that do not have any
ABI or API guarantees.

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

%{qt6_link_executables}

%ldconfig_scriptlets -n libQt6ShaderTools6

%files
%{_qt6_bindir}/qsb
%{_bindir}/qsb6

%files -n libQt6ShaderTools6
%license LICENSES/*
%{_qt6_libdir}/libQt6ShaderTools.so.*

%files devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtShaderToolsTestsConfig.cmake
%{_qt6_cmakedir}/Qt6ShaderTools/
%{_qt6_cmakedir}/Qt6ShaderToolsTools/
%{_qt6_descriptionsdir}/ShaderTools.json
%{_qt6_includedir}/QtShaderTools/
%{_qt6_libdir}/libQt6ShaderTools.prl
%{_qt6_libdir}/libQt6ShaderTools.so
%{_qt6_metatypesdir}/qt6shadertools_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_shadertools.pri
%{_qt6_pkgconfigdir}/Qt6ShaderTools.pc
%exclude %{_qt6_includedir}/QtShaderTools/%{real_version}/

%files private-devel
%{_qt6_includedir}/QtShaderTools/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_shadertools_private.pri

%endif

%changelog
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
- Drop patches, fixed upstream:
  * 0001-Fix-encoding-decoding-of-string-literals-for-big-end.patch
  * 0003-Use-intermOut.cpp-s-IsNan-and-IsInfinity-for-parse-t.patch
  * 0002-TIntermediate-promoteConstantUnion-fix-conversion-to.patch
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Fri Dec 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to fix endianness issues on big endian platforms:
  * 0001-Fix-encoding-decoding-of-string-literals-for-big-end.patch
  * 0002-TIntermediate-promoteConstantUnion-fix-conversion-to.patch
  * 0003-Use-intermOut.cpp-s-IsNan-and-IsInfinity-for-parse-t.patch
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.3:
  * https://www.qt.io/blog/qt-6.1.3-released
* Fri Jul  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.2. New bugfix release:
  * https://www.qt.io/blog/qt-6.1.2-released
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.1:
  * https://www.qt.io/blog/qt-6.1.1-released
* Thu May  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0:
  * https://www.qt.io/blog/qt-6.1-released
* Fri Apr 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-rc.
* Tue Apr 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta3.
* Wed Mar 31 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.3
  * https://www.qt.io/blog/qt-6.0.3-released
* Fri Mar 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta2
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta1
  https://www.qt.io/blog/qt-6.1-beta-released
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.2:
  https://www.qt.io/blog/qt-6.0.2-released
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.1
  https://www.qt.io/blog/qt-6.0.1-released
* Wed Dec 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use a different 'Name' when building the docs flavor.
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0:
  * https://www.qt.io/blog/qt-6.0-released
* Wed Dec  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Qt 6.0.0 RC2
* Wed Nov 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~rc1
* Tue Nov 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta5
* Tue Nov 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta4.
* Tue Oct 20 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0beta1
  https://www.qt.io/blog/qt-6.0-beta-released
* Tue Oct  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0-alpha
  https://www.qt.io/blog/qt-6.0-alpha-released
* Wed Jun  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-shadertools
